@@ -12,14 +12,13 @@ class Commands:
         self.user_dir = path
         self.project_token = project_token
         self.terminal_token = terminal_token
-        self.messages = []
-    
+        self.messages = []    
 
     # returns True if project already exists
     def generate(self):
         try:
             _dir = os.getcwd()
-            _res = requests.post('https://clix.dev/api/package/generate',
+            _res = requests.post('https://api.clix.dev/api/package/generate',
             data=json.dumps({
                 'terminal_token': self.terminal_token,
                 'project_token': self.project_token,
@@ -29,7 +28,7 @@ class Commands:
             if _res == False:
                 print('Please check your tokens and try again.\n')
                 return False
-
+            
             if _res.get('misc').get('project_path'):
                 if _res.get('misc').get('project_name') != _res.get('misc').get('last_generated_name'):
                     if os.path.exists(_res.get('misc').get('project_path') + _res.get('misc').get('last_generated_name') + "/"):
@@ -105,7 +104,7 @@ class Commands:
     # sync does remove the endpoint url tho
     def sync(self):
         try:
-            _res = requests.post('https://clix.dev/api/package/sync',
+            _res = requests.post('https://api.clix.dev/api/package/sync',
                                 data=json.dumps({
                                     'terminal_token': self.terminal_token,
                                     'project_token': self.project_token,
@@ -219,7 +218,7 @@ class Commands:
 
     def docs(self):
         try:
-            _res = requests.post('https://clix.dev/api/package/docs',
+            _res = requests.post('https://api.clix.dev/api/package/docs',
                                 data=json.dumps({
                                     'terminal_token': self.terminal_token,
                                     'project_token': self.project_token,
